@@ -14,11 +14,13 @@ from ..consts import CONFIG
 from ..consts import RAPPORT_HTML
 from ..consts import REST_CLIENT
 from ..consts import FUPDB_CREDENTIALS
+from ..consts import LOGS
 from ..customer import Customer
 from ..product import Product
 from ..product_gp import Product_GP
 from . import app
 
+
 import click
 import smtplib
 import tablib
@@ -44,6 +46,11 @@ def runserver(host, port):
 def sync(last_date, product_ese):
     """Mise à jour de la liste des clients Business ainsi que de leurs \
     relevés de consommation superieur a une date."""
+    LOGS.logger.info(
+        "Customers information and CDR synchronization START. "
+        "CDR date={}, enterprise={}"
+        .format(last_date, product_ese)
+    )
     if not product_ese:
         products = Product.all()
         for product in products:
@@ -58,6 +65,11 @@ def sync(last_date, product_ese):
             f = partial(core.update_customer_cdr, last_date)
             with Pool(processes=2) as pool:
                 pool.map(f, product.customers_ese)
+    LOGS.logger.info(
+        "Customers information and CDR synchronization END. "
+        "CDR date={}, enterprise={}"
+        .format(last_date, product_ese)
+    )
 
 
 @cmd.command()
@@ -167,6 +179,10 @@ def notify_try(start_date, stop_date):
 @cmd.command()
 @click.option('--product', is_flag=True, default=False)
 def reconciled(product):
+    LOGS.logger.info(
+        "FUP/DEFUP reconciliation START. Product={}"
+        .format(product)
+    )
     if not product:
         """compare les clients fupe dans aiguillier et api-fup"""
         subject = '[blueline] Reconcile FUP'
@@ -186,6 +202,9 @@ def reconciled(product):
                 CONFIG['AIGUILLIER']['password']
                 )
             )
+        LOGS.logger.info(
+            "Get fup-ed customers in Aiguiller: {}".format(response)
+        )
         infos = response['content']['fup']
         infos_aiguillier = [
                                 info['name'].lower()
@@ -351,6 +370,7 @@ def reconciled(product):
         msg.as_string()
         )
     s.quit()
+    LOGS.logger.info("Email '{}' sent to {}".format(msg['Subject'], msg['To']))
 
 
 @cmd.command()
