@@ -7,7 +7,8 @@ from .consts import CONFIG
 from .consts import FUPDB_CREDENTIALS
 from .consts import LOGS
 from .consts import REDIS_DB
-from .consts import REST_CLIENT, URL
+from .consts import REST_CLIENT
+from .consts import URL_V2
 from . import core
 from . import product
 
@@ -61,7 +62,10 @@ class Customer(object):
             ).format(self.table_customer)
         cursor.execute(sql, (self.name,))
         row = cursor.fetchone()
-        LOGS.logger.info("Result: {}".format(row))
+        LOGS.logger.info(
+            "Customer {} information from CDR database: {}"
+            .format(self.name, row)
+        )
         if not row:
             raise ValueError(
                 "Le client {name} n'existe pas".format(name=name)
@@ -69,7 +73,6 @@ class Customer(object):
         else:
             self.product = product.Product(row[1])
             self.refnum = row[0]
-        LOGS.logger.info(self.product)
 
     def __repr__(self):
         return '<Customer {name}>'.format(name=self.name)
@@ -81,6 +84,10 @@ class Customer(object):
             sql = "SELECT name FROM customer"
             rows = db.query(sql)
             customers = [Customer(row.name) for row in rows]
+        LOGS.logger.info(
+            "GP customers count fetched inside SI databse: {}"
+            .format(len(customers))
+        )
         return customers
 
     @staticmethod
@@ -94,6 +101,10 @@ class Customer(object):
             sql = "SELECT name FROM customer_ese"
             rows = db.query(sql)
             customers = [Customer(row.name, **kwargs) for row in rows]
+        LOGS.logger.info(
+            "ESE customers count fetched inside SI databse: {}"
+            .format(len(customers))
+        )
         return customers
 
     def customers_fup(self):
@@ -106,7 +117,6 @@ class Customer(object):
                 "WHERE customer=:customer and datetime=(SELECT max(datetime)"
                 " from fup WHERE customer=:customer)"
                 )
-            LOGS.logger.info(sql)
             rows = db.query(
                 sql,
                 customer=self.name,
@@ -118,6 +128,10 @@ class Customer(object):
                     'conso': row.conso,
                     'policy': row.policy
                     }
+                LOGS.logger.info(
+                    "Customer '{}' status in SI database: {}"
+                    .format(self.name, infos)
+                )
         return infos
 
     @property
@@ -137,10 +151,14 @@ class Customer(object):
                         'status': row.status
                         }
                     )
+            LOGS.logger.info(
+                "Customer '{}' FUP history in SI database: {}"
+                .format(self.name, result)
+            )
         return result
 
     def set_refnum(self, refnum):
-        """Changement du refnum"""
+        """Mise à jour du refnum du client dans la base SI"""
         url = core.database_url(**FUPDB_CREDENTIALS)
         with records.Database(url) as db:
             sql = (
@@ -153,18 +171,14 @@ class Customer(object):
                 refnum=refnum,
                 name=self.name
                 )
-        log_msg = (
-            "Changement de refnum de {}: {} => {}"
-            ).format(
-                self.name,
-                self.refnum,
-                refnum
-                )
-        LOGS.logger.info(log_msg)
+        LOGS.logger.info(
+            "Customer '{}' reference number updated from {} to {}"
+            .format(self.name, self.refnum, refnum)
+        )
         self.refnum = refnum
 
     def set_product(self, product_name):
-        """Changement du produit"""
+        """Mise à jour du produit du client dans la base SI"""
         url = core.database_url(**FUPDB_CREDENTIALS)
         with records.Database(url) as db:
             sql = (
@@ -177,19 +191,17 @@ class Customer(object):
                 product=product_name,
                 name=self.name
                 )
-        log_msg = (
-            "Changement de produit de {}: {} => {}"
-            ).format(
-                self.name,
-                self.product.name,
-                product_name
-                )
-        LOGS.logger.info(log_msg)
+        LOGS.logger.info(
+            "Customer '{}' product updated from {} to {}"
+            .format(self.name, self.product, product_name)
+        )
         self.product = product.Product(product_name)
 
     def start_consumptions(self, start_conso):
-        """enregistre dans redis la date a partir de """
-        """laquelle on calcul la conso fup d'un client"""
+        """
+        enregistre dans redis la date a partir de
+        laquelle on calcul la conso fup d'un client
+        """
         result = {}
         key = 'cdr_start_date:{}'.format(self.name)
         time_expire = datetime.strptime(
@@ -211,11 +223,11 @@ class Customer(object):
                 'date': str(start.decode('utf-8')),
                 'expire': str(time_expire)
                 }
-        LOGS.logger.info('key enregistré:{}-{}-{}'.format(
-            key,
-            start_conso,
-            time_expire
-            ))
+        LOGS.logger.info(
+            "Clé Redis de la transaction: {}, début de la consommation: {}, "
+            "date d'expiration{}"
+            .format(key, start_conso, time_expire)
+        )
         return result
 
     def fup_defup(
@@ -229,31 +241,28 @@ class Customer(object):
             msg
             ):
         api_request = getattr(REST_CLIENT, method)
-        LOGS.logger.info(api_request)
-        LOGS.logger.info(params)
-        # response = api_request(
-        #     '/fup',
-        #     auth=(
-        #         CONFIG['AIGUILLIER']['username'],
-        #         CONFIG['AIGUILLIER']['password']
-        #         ),
-        #     params=params
-        #     )
-        response = requests.delete(
-            '{}/consommation?remettre_normal={}&periode={}'.format(
-                URL,
-                self.nam,
-                period
-                ),
+        response = api_request(
+            '/fup',
             auth=(
                 CONFIG['AIGUILLIER']['username'],
                 CONFIG['AIGUILLIER']['password']
-                )
+                ),
+            params=params
             )
-        response = response.json()
-        LOGS.logger.info('AIGUILLIER RESPONSE: {}'.format(
-            response
-            ))
+        LOGS.logger.info(
+            "[FUP/DEFUP] Customer {} {operation} from Aiguiller: "
+            "api request: {}, "
+            "parameters: {}, "
+            "response: {} {}"
+            .format(
+                self.name,
+                api_request,
+                params,
+                response,
+                response.text,
+                operation=msg,
+            )
+        )
         LOGS.logger.info("{} un client {}-{}-{}-{}".format(
             msg,
             self.name,
@@ -281,6 +290,10 @@ class Customer(object):
                     status=db_status,
                     conso=str(conso)
                     )
+            LOGS.logger.info(
+                "[FUP/DEFUP] Customer {} added to SI FUP database."
+                .format(self.name)
+            )
             result = {
                 'code': '200',
                 'message': '{} reussit'.format(msg)
@@ -293,7 +306,10 @@ class Customer(object):
         return result
 
     def defup_from_aiguillier(self, bool_defup):
-        """défuper ou fuper un client"""
+        """
+
+        :bool_defup:
+        """
         result = {
             'code': '401',
             'message': 'NOK'
@@ -353,7 +369,6 @@ class Customer(object):
                             }
             else:
                 if not status and not bool_defup:
-                    LOGS.logger.info('innnnnnnnn')
                     result = self.fup_defup(
                         method,
                         params,
@@ -370,11 +385,45 @@ class Customer(object):
                             'code': '204',
                             'message': 'produit non {}'.format(msg)
                             }
+        # defup aiguiller v2
+        if bool_defup:
+            res = requests.delete('{}={}&periode={}'.format(
+                URL_V2,
+                self.name,
+                period
+                ),
+                auth=(
+                    CONFIG['AIGUILLIER']['username'],
+                    CONFIG['AIGUILLIER']['password']
+                    )
+                )
+            if res.status_code == 200:
+                res = res.json()
+                if res['status'] == '200':
+                    LOGS.logger.info(
+                        "[DEFUP] Customer {} removed from DT database"
+                        .format(self.name)
+                    )
+                else:
+                    LOGS.logger.error(
+                        "[DEFUP] Unable to remove customer {} from DT database"
+                        .format(self.name)
+                    )
+            else:
+                LOGS.logger.error(
+                    "[DEFUP] Unable to remove customer {} from DT database"
+                    .format(self.name)
+                )
+
         if bool_delete and bool_defup:
             url = core.database_url(**FUPDB_CREDENTIALS)
             with records.Database(url) as db:
                 sql = "DELETE FROM customer WHERE name=:name"
                 db.query(sql, name=self.name)
+            LOGS.logger.info(
+                "[DEFUP] Customer {} removed from SI FUP database"
+                .format(self.name)
+            )
         return result
 
     def get_cdr_from_aiguillier(self, last_date):
@@ -388,6 +437,10 @@ class Customer(object):
         for i in range(3):
             if OK:
                 break
+            msg = (
+                "Try {}/3: Fetching customer {} CDR from {} from Aiguiller: "
+                .format(i, self.name, last_date)
+            )
             try:
                 response = REST_CLIENT.get(
                     '/fup',
@@ -397,30 +450,12 @@ class Customer(object):
                         ),
                     params={'customer': self.name, 'fromdate': last_date}
                     )
-                LOGS.logger.info("essai {} de {}".format(i, self.name))
+                LOGS.logger.info(msg + str(response))
                 infos = response['content']
-                LOGS.logger.warn('Value {}'.format(infos))
                 if infos['status']:
                     OK = True
-            except requests.exceptions.Timeout:
-                LOGS.logger.info("essai TimeoutError {} de {}".format(
-                    i,
-                    self.name
-                    ))
-                time.sleep(60)
-                continue
-            except ValueError:
-                LOGS.logger.info("essai ValueError {} de {}".format(
-                    i,
-                    self.name
-                    ))
-                time.sleep(60)
-                continue
-            except Exception:
-                LOGS.logger.info("essai ExceptionError {} de {}".format(
-                    i,
-                    self.name
-                    ))
+            except Exception as e:
+                LOGS.logger.error(msg + str(e))
                 time.sleep(60)
                 continue
         # nill_condition = (
@@ -516,7 +551,6 @@ class Customer(object):
                     "DELETE FROM {} WHERE customer=:name "
                     "AND datetime>=:start AND datetime<=:stop"
                     ).format(self.table_cdr)
-                LOGS.logger.info(sql)
                 # start_date = date.strftime('%Y%m%d')+last_date[-6:]
                 start_date = datetime.strptime(
                     str(last_date),
@@ -543,8 +577,11 @@ class Customer(object):
                     "(:name, :date_time, :source, "
                     ":octetsin, :octetsout, :product)"
                     ).format(self.table_cdr)
-                LOGS.logger.info(sql)
                 db.bulk_query(sql, *params)
+                LOGS.logger.info(
+                    "Parameters inserted inside SI database: {}"
+                    .format(params)
+                )
         return result
 
     def get_cdr(self, start=None, stop=None, product_out_fup=False):
@@ -565,7 +602,7 @@ class Customer(object):
                 )
         LOGS.logger.info(
             "Recuperation des CDRS de {customer} "
-            "du {start} au {stop} dans table {table}".format(
+            "du {start} au {stop} dans table {table} ...".format(
                 customer=self.name,
                 start=start.strftime('%d%m%Y'),
                 stop=stop.strftime('%d%m%Y'),
@@ -604,7 +641,7 @@ class Customer(object):
             infos = groupby(infos, key=lambda x: x['date'])
             for date, data in infos:
                 cdrs[date.strftime('%d%m%Y')] = list(data)
-        LOGS.logger.info("CDRS Recupere")
+        LOGS.logger.info("Customer {} CRD: {}".format(self.name, cdrs))
         return cdrs
 
     def filter_cdrs_policy_wise(self, cdrs, product_out_fup=False):
@@ -763,6 +800,10 @@ class Customer(object):
                     status = row.status
                 else:
                     status = False
+                LOGS.logger.info(
+                    "Customer {} fup status in SI database: {}"
+                    .format(self.name, status)
+                )
             if info['total'] >= info['data_limit'] and not status:
                 info['fup_in'] = True
             elif info['total'] < info['data_limit'] and status:
