@@ -57,6 +57,10 @@ class Product(object):
                 'interval': interval,
                 'name_type': name_type[len(name_type)-2]
                 }
+        LOGS.logger.info(
+            "Product '{}' information: policies={}, no_policies={}"
+            .format(name, self.policies, self.no_policies)
+        )
 
     def __repr__(self):
         return '<Product {name}>'.format(name=self.name)
@@ -69,6 +73,10 @@ class Product(object):
             c for c in Customer.all()
             if c.product.name == self.name
             ]
+        LOGS.logger.info(
+            "GP Customers count using {} product from SI database: {}"
+            .format(self.name, len(customers))
+        )
         return customers
 
     @property
@@ -79,6 +87,10 @@ class Product(object):
             c for c in Customer.all_ese()
             if c.product.name == self.name
             ]
+        LOGS.logger.info(
+            "ESE Customers count using {} product from SI database: {}"
+            .format(self.name, len(customers))
+        )
         return customers
 
     @staticmethod
@@ -207,10 +219,14 @@ class Product(object):
         customers = self.get_customers_aiguillier()
         url = core.database_url(**FUPDB_CREDENTIALS)
         if not product_ese:
-            LOGS.logger.info("update customer")
             with records.Database(url) as db:
                 sql = "DELETE FROM customer WHERE product=:product"
                 db.query(sql, product=str(self.name))
+            LOGS.logger.info(
+                "GP Customers owning the product {} have been deleted from "
+                "SI database"
+                .format(self.name)
+            )
             existing_customers = {
                 customer.name: {
                     'product': customer.product,
@@ -242,6 +258,7 @@ class Product(object):
                         # le client n'existe vraiment pas dans la base
                         # on va le créer
                         # url = core.database_url(**FUPDB_CREDENTIALS)
+
                         with records.Database(url) as db:
                             sql = (
                                 "INSERT INTO customer (name, refnum, product) "
@@ -255,11 +272,9 @@ class Product(object):
                                 product=infos['product']
                                 )
                         LOGS.logger.info(
-                            "Inscription du client {} "
-                            "in table customer".format(
-                                customer
-                                )
-                            )
+                            "GP Customer {} created in customer table"
+                            .format(customer)
+                        )
                     else:
                         # le client existe déjà dans la base
                         # donc c'est forcément son produit qui a changé
@@ -281,7 +296,7 @@ class Product(object):
                                     )
                                 if status[0]['status']:
                                     # si le client était fup, il faut le défup
-                                    REST_CLIENT.delete(
+                                    response = REST_CLIENT.delete(
                                         '/fup',
                                         auth=(
                                             CONFIG['AIGUILLIER']['username'],
@@ -289,6 +304,11 @@ class Product(object):
                                             ),
                                         params={'customer': self.name}
                                         )
+                                    LOGS.logger.info(
+                                        "[DEFUP] Removing customer {} "
+                                        "previous product from fup list: {}"
+                                        .format(customer, response.text)
+                                    )
         else:
             kwargs = {
                 'table_customer': 'customer_ese',
@@ -297,6 +317,11 @@ class Product(object):
             with records.Database(url) as db:
                 sql = "DELETE FROM customer_ese WHERE product=:product"
                 db.query(sql, product=str(self.name))
+            LOGS.logger.info(
+                "ESE customers owning the product {} have been deleted from "
+                "SI database"
+                .format(self.name)
+            )
             for customer, infos in customers.items():
                 # soit le client 'customer' n'existe pas
                 # soit il n'a pas le produit 'self.name'
@@ -312,7 +337,6 @@ class Product(object):
                             "INSERT INTO customer_ese (name, refnum, "
                             "product) VALUES (:name, :refnum, :product)"
                             )
-                        LOGS.logger.info(sql)
                         db.query(
                             sql,
                             name=customer,
@@ -320,11 +344,9 @@ class Product(object):
                             product=infos['product']
                             )
                     LOGS.logger.info(
-                        "Inscription du client {} "
-                        "in table customer_ese".format(
-                            customer
-                            )
-                        )
+                        "ESE Customer {} created in customer table"
+                        .format(customer)
+                    )
                 else:
                     # le client existe déjà dans la base
                     # donc c'est forcément son produit qui a changé
